
# vim: syntax=puppet

# This module installs an EPrints server, including mysql & apache
# Use additional modules to configure an actual repository.

# Author: Christopher Gutteridge


class uos_eprints_ras( ) {

  class { 'uos_mysql_server':  
  }

  class { 'uos_httpd':
    user  => 'eprints',
    group => 'eprints',
  }

  include uos_linux_firewall::allow_http

  # RPM Packages
  ensure_packages( [ 
      'libxml2',
      'libxslt',
      'libxslt-devel',
      'mod_perl',
      'perl-DBI',
      'perl-DBD-MySQL',
      'perl-IO-Socket-SSL',
      'perl-Time-HiRes',
      'perl-CGI',
      'perl-Digest-MD5',
      'perl-Digest-SHA',
      'perl-JSON',
      'perl-XML-LibXML',
      'perl-XML-LibXSLT',
      'perl-XML-SAX',
      'perl-Apache-DBI',
      'perl-IO-String',
      'perl-MIME-Lite',
      'perl-Text-Unidecode',
      'perl-Unicode-Collate',
      'perl-Pod-LaTeX',
      'tetex-latex',
      'wget',
      'gzip',
      'tar',
      'ImageMagick',
      'poppler-utils',
      'chkconfig',
      'unzip',
      'cpan',
      'gcc',
      'git', 
      'elinks', 
    ],
    {'ensure' => 'present'}
  )

  # Install a perl package that doesn't exist as an available RPM 
  include cpanm
  cpanm { 'TeX::Encode':
    ensure => latest,
  }
  # and this one is needed to make the indexer init.d script work
  cpanm { 'Config::General':
    ensure => latest,
  }
   

  # install EPrints
  package { 'eprints':
    provider => 'rpm',
    ensure   => installed,
    source   => 'puppet:///modules/uos_eprints_ras/eprints-3.4.3-1.el7.noarch.rpm',
  }

  # make a place to put repositories on the big partition 
  # we make two directories... the top level /srv/eprints can also store tools relating to the repositories
  file { '/srv/eprints':
    ensure => directory,
    owner   => 'eprints',
    group   => 'eprints',
  }     
  file { '/srv/eprints/archives':
    ensure => directory,
    owner   => 'eprints',
    group   => 'eprints',
  }     

  file { '/etc/httpd/conf.d/eprints_ssl.conf':
    content => "# This file was created by the puppet EPrints installer\nInclude /srv/eprints/archives/*/ssl/securevhost.conf\n",
    notify  => Service['httpd'],
  }

  file { '/usr/share/eprints/cfg/apache.conf':
    content => "# This file was created by the puppet EPrints installer\n<Directory /usr/share/eprints/archives>\nOptions FollowSymLinks\n</Directory>\nLoadModule perl_module modules/mod_perl.so\nPerlSwitches -I/usr/share/eprints/perl_lib\nInclude /usr/share/eprints/cfg/perl_module_isolation.conf\n",
    require => Package['eprints'],
    notify  => Service['httpd'],
  }

  file { '/usr/share/eprints/flavours/pub_lib':
      ensure  => 'directory',
      path    => '/usr/share/eprints/flavours/pub_lib',
      recurse => 'remote',
      seltype => 'httpd_sys_content_t',
      owner   => 'eprints',
      group   => 'eprints',
      source  => 'puppet:///modules/uos_eprints_ras/pub_lib',
      require => Package['eprints'],
      notify  => Service['httpd'],
  }

  #TODO cron

  # symlink the indexer starting script
  file { "/usr/share/eprints/bin/epindexer":
    ensure  => "link",
    target  => "/etc/init.d/epindexer",
    notify  => Service['httpd'],
    require => Package['eprints'],
    before  => Service['epindexer'],
  }

  # and set up the indexer service 
  service { "epindexer":
    ensure => "running",
    enable => "true",
  }

}

